@@ -1,4 +1,9 @@
-use crate::request::prelude::*;
+use crate::{
+    client::Client,
+    error::Error,
+    request::{Pending, Request},
+    routing::Route,
+};
 use twilight_model::{
     channel::Message,
     id::{ChannelId, MessageId},
@@ -22,7 +27,7 @@ impl<'a> CrosspostMessage<'a> {
         }
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), Error> {
         let request = Request::from_route(Route::CrosspostMessage {
             channel_id: self.channel_id.0,
             message_id: self.message_id.0,
