@@ -296,7 +296,8 @@ impl<'a> UpdateChannel<'a> {
     fn start(&mut self) -> Result<(), HttpError> {
         let mut request = Request::builder(Route::UpdateChannel {
             channel_id: self.channel_id.0,
-        });
+        })
+        .json(&self.fields)?;
 
         if let Some(reason) = &self.reason {
             request = request.headers(request::audit_header(reason)?);
