@@ -6,6 +6,7 @@ mod delete_webhook_message;
 mod execute_webhook;
 mod get_channel_webhooks;
 mod get_webhook;
+mod get_webhook_message;
 mod update_webhook;
 mod update_webhook_with_token;
 
@@ -13,6 +14,7 @@ pub use self::{
     create_webhook::CreateWebhook, delete_webhook::DeleteWebhook,
     delete_webhook_message::DeleteWebhookMessage, execute_webhook::ExecuteWebhook,
     get_channel_webhooks::GetChannelWebhooks, get_webhook::GetWebhook,
-    update_webhook::UpdateWebhook, update_webhook_message::UpdateWebhookMessage,
+    get_webhook_message::GetWebhookMessage, update_webhook::UpdateWebhook,
+    update_webhook_message::UpdateWebhookMessage,
     update_webhook_with_token::UpdateWebhookWithToken,
 };
