@@ -198,6 +198,7 @@ impl<'a> UpdateWebhookMessage<'a> {
     ///
     /// If called, all unspecified attachments will be removed from the message.
     /// If not called, all attachments will be kept.
+    #[deprecated(since = "0.5.5", note = "will be removed in favor of `attachments`")]
     pub fn attachment(mut self, attachment: Attachment) -> Self {
         self.fields.attachments.push(attachment);
 
@@ -328,6 +329,7 @@ impl<'a> UpdateWebhookMessage<'a> {
     /// Attach a file to the webhook.
     ///
     /// This method is repeatable.
+    #[deprecated(since = "0.5.5", note = "will be removed in favor of `files`")]
     pub fn file(mut self, name: impl Into<String>, file: impl Into<Vec<u8>>) -> Self {
         self.files.push((name.into(), file.into()));
 
@@ -337,11 +339,13 @@ impl<'a> UpdateWebhookMessage<'a> {
     /// Attach multiple files to the webhook.
     pub fn files<N: Into<String>, F: Into<Vec<u8>>>(
         mut self,
-        attachments: impl IntoIterator<Item = (N, F)>,
+        files: impl IntoIterator<Item = (N, F)>,
     ) -> Self {
-        for (name, file) in attachments {
-            self = self.file(name, file);
-        }
+        self.files.extend(
+            files
+                .into_iter()
+                .map(|(name, file)| (name.into(), file.into())),
+        );
 
         self
     }
